@@ -5,9 +5,9 @@ class Imp < Formula
   homepage 'https://integrativemodeling.org/'
   url 'https://integrativemodeling.org/2.8.0/download/imp-2.8.0.tar.gz'
   sha256 '83a23c56f0be9de8900d0edd3978eb8c2637e6d5086f7ef7e2cd61f0b7a5aa80'
-  revision 12
+  revision 14
 
-  # Fix to work with latest CGAL (4.11)
+  # Fix to work with latest CGAL (4.11 or later)
   patch do
     url "https://github.com/salilab/imp/commit/a8ef53c.patch?full_index=1"
     sha256 "bf712504c1452aab3608d239bc973a56a7d6c05a2a420bac6677e7588c146bcf"
@@ -45,6 +45,8 @@ class Imp < Formula
     # Don't link against gperftools, even if they were found, since then the
     # bottle won't work on systems without gperftools installed
     args << "-DGPerfTools_found=0"
+    # Help cmake to find CGAL
+    ENV["CGAL_DIR"] = Formula["cgal"].lib/"cmake/CGAL"
     mkdir "build" do
       system "cmake", *args
       system "make"
@@ -67,11 +69,12 @@ class Imp < Formula
   end
 
   test do
-    Language::Python.each_python(build) do |python, version|
-      system python, "-c", "import IMP"
-      system python, "-c", "import IMP.em2d"
-      system python, "-c", "import IMP.foxs"
-      system python, "-c", "import IMP.multifit"
+    Language::Python.each_python(build) do |python, pyver|
+      system python, "-c", "import IMP; assert(IMP.__version__ == '#{version}')"
+      system python, "-c", "import IMP.em2d; assert(IMP.em2d.__version__ == '#{version}')"
+      system python, "-c", "import IMP.cgal; assert(IMP.cgal.__version__ == '#{version}')"
+      system python, "-c", "import IMP.foxs; assert(IMP.foxs.__version__ == '#{version}')"
+      system python, "-c", "import IMP.multifit; assert(IMP.multifit.__version__ == '#{version}')"
     end
     system "multifit"
     system "foxs"
